<?php

namespace Drupal\tsk\Commands;

use Drush\Commands\DrushCommands;
use Drupal\tsk\Services\TskService;

/**
 * Drush integration for the module Temporary Storages Killer.
 */
class TskCommands extends DrushCommands {

  /**
   * @var \Drupal\tsk\Services\TskService
   */
  protected $tskService;

  /**
   * TskCommands constructor.
   *
   * @param \Drupal\tsk\Services\TskService $tsk_service
   *   Temporary Storage Killer service.
   */
  public function __construct(TskService $tsk_service) {
    $this->tskService = $tsk_service;
  }

  /**
   * Kills the specified temporary storages.
   *
   * @command temp-store-killer:all
   * @aliases tska
   * @usage drush temp-store-killer:all
   *   Kills the specified temporary storages.
   */
  public function killAll() {
    $this->tskService->killAll();
  }

  /**
   * Kills a temporary storage.
   *
   * @command temp-store-killer
   * @aliases tsk
   * @param string $type
   *   Type of the collection: private / shared
   * @param string $collection
   *   The collection name to use for this key/value store.
   * @param string $key
   *   The key of the stored data.
   * @usage drush temp-store-killer type collection key
   *   Kills a temporary storage.
   */
  public function kill(string $type, string $collection, string $key = '') {
    $private = $type === 'private';
    $kill_all = empty($key);
    $this->tskService->kill($collection, $private, $kill_all, $key);
  }

}
