<?php

namespace Drupal\tsk\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\tsk\Entity\TskEntity;
use Drupal\tsk\Services\TskService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines TskController class.
 */
class TskController extends ControllerBase {

  /**
   * @var \Drupal\simple_sitemap\Simplesitemap
   */
  protected $tskService;

  /**
   * TskController constructor.
   *
   * @param \Drupal\tsk\Services\TskService $tsk_service
   *   Temporary Storage Killer service.
   */
  public function __construct(TskService $tsk_service) {
    $this->tskService = $tsk_service;
  }

  /**
   * {@inheritdoc}
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The Drupal service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('tsk.service')
    );
  }

  /**
   * Delete temporary storage for the specified TSK entity.
   *
   * @param \Drupal\tsk\Entity\TskEntity $tsk_entity
   *   Temporary storage entity.
   */
  public function kill(TskEntity $tsk_entity) {
    $this->tskService->kill($tsk_entity->collection, $tsk_entity->private, $tsk_entity->kill_all, $tsk_entity->key);
    $this->messenger()->addStatus(t('The temporary storage has been deleted.'));
    return $this->redirect('entity.tsk_entity');
  }

  /**
   * Delete all specified temporary storages.
   */
  public function killAll() {
    $this->tskService->killAll();
    $this->messenger()->addStatus(t('The temporary storages have been deleted.'));
    return $this->redirect('entity.tsk_entity');
  }

}
